/*****************************************************************************
/*
/*            INSTITUTO NACIONAL PARA LA EVALUACIN DE LA EDUCACIN
/*                       DIRECCIN DE PRUEBAS Y MEDICIN
/*                           SUBDIRECCION DE ANLISIS
/*_____________________________________________________________________________
/*
/*            EXAMENES DE LA CALIDAD Y EL LOGRO EDUCATIVOS (Excale)
/*                    TERCER GRADO DE SECUNDARIA (Excale 09)
/*
/*                          **** ESCRITURA ****
/*
/*                     Ciclo escolar evaluado: 2007 - 2008
/*_____________________________________________________________________________
/*
/*
/*       PROGRAMA PARA CONSTRUIR LA BASE DE DATOS DE ALUMNOS DE ESCRITURA
/*                               EN FORMATO SAS
/*_____________________________________________________________________________
/*
/*  El programa convierte al archivo Excale09_2008_Alum_Esc.txt, el cual est en
/*  formato ASCII, en una base de datos en formato SAS. El programa realiza las
/*  siguientes tareas:
/*   - Declara formatos para algunas variables
/*   - Lee las variables del archivo en formato ASCII
/*   - Declara los valores considerados en el anlisis como perdidos (missing values)
/*
/* INSTRUCCIONES
/*  Para construir la base de datos (tabla de datos) es necesario:
/*      1) Crear una carpeta de trabajo y colocar en ella al archivo Excale09_2008_Alum_Esc.txt
/*         as como el archivo Excale09_2008_Alum_Esc.SAS (este archivo) los cules se pueden
/*         descargar del sitio web del INEE (www.inee.edu.mx).
/*      2) Modificar la primera y segunda lnea de los comandos de este archivo
/*         (libname y filename) para actualizar el nombre de la librera y el archivo
/*         de trabajo.
/*      3) Ejecutar el programa del archivo.
/*
/*  Al finalizar, se deber contar con la base de datos (tabla de datos) Excale09_2008_Alum_Esc.sas7bdat
/*
/*  Posteriormente, cuando se desee utilizar nuevamente la base Excale09_2008_Alum_Esc.sas7bdat,
/*  se deber ejecutar primero el procedimiento FORMAT ("proc FORMAT") de este programa para que
/*  SAS cargue los formatos necesarios para abrir la base.
/*
/* CONTACTO:
/*
/*      Para mayor informacin o aclaracin de dudas favor de contactar a la
/*      Subdireccin de Anlisis del Instituto
/*      Correo electrnico: excale.analisis@inee.edu.mx
/*      Tel 5482 0900 Ext. 1082
/*      Domicilio: Jos Ma. Velasco No. 101. 3er piso. Col. San Jos Insurgentes
/*                 Del. Benito Jurez. Mxico. D.F.
/*
/* FECHA DE LIBERACIN: 16 DE MARZO DEL 2010
/*
*  ****************************************************************************/

LIBNAME  INEE  "C:\***\";
FILENAME alum  "C:\***\Excale09_2008_Alum_Esc.TXT";

PROC FORMAT;
     VALUE id_entF     1         ="Aguascalientes"
                       2         ="Baja California"
                       3         ="Baja California Sur"
                       4         ="Campeche"
                       5         ="Coahuila"
                       6         ="Colima"
                       7         ="Chiapas"
                       8         ="Chihuahua"
                       9         ="Distrito Federal"
                       10        ="Durango"
                       11        ="Guanajuato"
                       12        ="Guerrero"
                       13        ="Hidalgo"
                       14        ="Jalisco"
                       15        ="Mxico"
                       16        ="Michoacn"
                       17        ="Morelos"
                       18        ="Nayarit"
                       19        ="Nuevo Len"
                       20        ="Oaxaca"
                       21        ="Puebla"
                       22        ="Quertaro"
                       23        ="Quintana Roo"
                       24        ="San Luis Potos"
                       25        ="Sinaloa"
                       26        ="Sonora"
                       27        ="Tabasco"
                       28        ="Tamaulipas"
                       29        ="Tlaxcala"
                       30        ="Veracruz"
                       31        ="Yucatn"
                       32        ="Zacatecas";
     VALUE id_modF     1         ="Urbana Pblica"
                       2         ="Rural Pblica"
                       3         ="Educacin Indgena"
                       4         ="Curso Comunitaria"
                       5         ="Privada"
                       6         ="General"
                       7         ="Tcnica"
                       8         ="Telesecundaria"
                       9         ="Privada";
     VALUE $modF       "GRAL"    ="General"
                       "TEC"     ="Tcnica"
                       "TV"      ="Telesecundaria"
                       "PRIV"    ="Privada";
     VALUE $mageb05f   "R"       ="Escuela rural"
                       "UA"      ="Escuela urbana de alta marginacin"
                       "UB"      ="Escuela urbana de baja marginacin"
                       "NA"      ="No aplica";
     VALUE sexoF       1         ="Hombre"
                       2         ="Mujer"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE edadF       99        ="Respuesta omitida";
     VALUE edadcF      1         ="14 aos o menos"
                       2         ="15 aos"
                       3         ="16 aos"
                       4         ="17 aos o ms"
                       9         ="Respuesta omitida";
     VALUE edadnF      1         ="Edad normativa"
                       2         ="Extra-edad"
                       9         ="Respuesta omitida";
     VALUE edad_acF    98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE mes_nacF    1         ="Enero"
                       2         ="Febrero"
                       3         ="Marzo"
                       4         ="Abril"
                       5         ="Mayo"
                       6         ="Junio"
                       7         ="Julio"
                       8         ="Agosto"
                       9         ="Septiembre"
                       10        ="Octubre"
                       11        ="Noviembre"
                       12        ="Diciembre"
                       98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE docenteF    99999     ="Respuesta omitida";
     VALUE R1_R25F     0         ="Fallo"
                       1         ="Acierto (pregunta dicotmica)/Acierto parcial (Pregunta politmica)"
                       2         ="Acierto total (pregunta dicotmica)"
                       5         ="Reactivo no alcanzado (se considera como no administrado)"
                       6         ="Reactivo no administrado por error de impresin"
                       7         ="Reactivo no administrado (No se incluy en su cuadernillo de examen)";
RUN;



DATA INEE.Excale09_2008_Alum_Esc;
   LENGTH
       nacional           3
       escuela            4
       id_ent             3
       nom_ent            $19
       id_mod             3
       mod                $4
       mageb05            $2
       estrato            $7
       entest             $6
       alumno             6
       id_instr           $16
       sexo               3
       edad               8
       edadc              3
       edadn              3
       edad_ac            3
       mes_nac            3
       w_alu              8
       docente            5
       sr_01              3
       sr_02              3
       sr_03              3
       sr_04              3
       sr_05              3
       sr_06              3
       sr_07              3
       sr_08              3
       sr_09              3
       sr_10              3
       sr_11              3
       sr_12              3
       sr_13              3
       sr_14              3
       sr_15              3
       sr_16              3
       sr_17              3
       sr_18              3
       sr_19              3
       sr_20              3
       sr_21              3
       sr_22              3
       sr_23              3
       sr_24              3
       sr_25              3
       sr_26              3
       sr_27              3
       sr_28              3
       sr_29              3
       sr_30              3
       sr_31              3
       sr_32              3
       sr_33              3
       sr_34              3
       sr_35              3
       sr_36              3
       sr_37              3
       sr_38              3
       sr_39              3
       sr_40              3
       sr_41              3
       sr_42              3
       sr_43              3
       sr_44              3
       sr_45              3
       sr_46              3
       pv1expesc          8
       pv2expesc          8
       pv3expesc          8
       pv4expesc          8
       pv5expesc          8
       wvarstrr           3
       w_fstr1            8
       w_fstr2            8
       w_fstr3            8
       w_fstr4            8
       w_fstr5            8
       w_fstr6            8
       w_fstr7            8
       w_fstr8            8
       w_fstr9            8
       w_fstr10           8
       w_fstr11           8
       w_fstr12           8
       w_fstr13           8
       w_fstr14           8
       w_fstr15           8
       w_fstr16           8
       w_fstr17           8
       w_fstr18           8
       w_fstr19           8
       w_fstr20           8
       w_fstr21           8
       w_fstr22           8
       w_fstr23           8
       w_fstr24           8
       w_fstr25           8
       w_fstr26           8
       w_fstr27           8
       w_fstr28           8
       w_fstr29           8
       w_fstr30           8
       w_fstr31           8
       w_fstr32           8
       w_fstr33           8
       w_fstr34           8
       w_fstr35           8
       w_fstr36           8
       w_fstr37           8
       w_fstr38           8
       w_fstr39           8
       w_fstr40           8
       w_fstr41           8
       w_fstr42           8
       w_fstr43           8
       w_fstr44           8
       w_fstr45           8
       w_fstr46           8
       w_fstr47           8
       w_fstr48           8
       w_fstr49           8
       w_fstr50           8
       w_fstr51           8
       w_fstr52           8
       w_fstr53           8
       w_fstr54           8
       w_fstr55           8
       w_fstr56           8
       w_fstr57           8
       w_fstr58           8
       w_fstr59           8
       w_fstr60           8
       w_fstr61           8
       w_fstr62           8
       w_fstr63           8
       w_fstr64           8
       w_fstr65           8
       w_fstr66           8
       w_fstr67           8
       w_fstr68           8
       w_fstr69           8
       w_fstr70           8
       w_fstr71           8
       w_fstr72           8
       w_fstr73           8
       w_fstr74           8
       w_fstr75           8
       w_fstr76           8
       w_fstr77           8
       w_fstr78           8
       w_fstr79           8
       w_fstr80           8
 ;

INFILE alum MISSOVER LINESIZE = 1070;
   INPUT
       nacional          1 - 1
       escuela           2 - 5
       id_ent            6 - 7
       nom_ent           8 - 26
       id_mod           27 - 27
       mod              28 - 31
       mageb05          32 - 33
       estrato          34 - 40
       entest           41 - 46
       alumno           47 - 52
       id_instr         53 - 68
       sexo             69 - 69
       edad             70 - 80
       edadc            81 - 81
       edadn            82 - 82
       edad_ac          83 - 84
       mes_nac          85 - 86
       w_alu            87 - 97
       docente          98 - 102
       sr_01           103 - 103
       sr_02           104 - 104
       sr_03           105 - 105
       sr_04           106 - 106
       sr_05           107 - 107
       sr_06           108 - 108
       sr_07           109 - 109
       sr_08           110 - 110
       sr_09           111 - 111
       sr_10           112 - 112
       sr_11           113 - 113
       sr_12           114 - 114
       sr_13           115 - 115
       sr_14           116 - 116
       sr_15           117 - 117
       sr_16           118 - 118
       sr_17           119 - 119
       sr_18           120 - 120
       sr_19           121 - 121
       sr_20           122 - 122
       sr_21           123 - 123
       sr_22           124 - 124
       sr_23           125 - 125
       sr_24           126 - 126
       sr_25           127 - 127
       sr_26           128 - 128
       sr_27           129 - 129
       sr_28           130 - 130
       sr_29           131 - 131
       sr_30           132 - 132
       sr_31           133 - 133
       sr_32           134 - 134
       sr_33           135 - 135
       sr_34           136 - 136
       sr_35           137 - 137
       sr_36           138 - 138
       sr_37           139 - 139
       sr_38           140 - 140
       sr_39           141 - 141
       sr_40           142 - 142
       sr_41           143 - 143
       sr_42           144 - 144
       sr_43           145 - 145
       sr_44           146 - 146
       sr_45           147 - 147
       sr_46           148 - 148
       pv1expesc       149 - 156
       pv2expesc       157 - 164
       pv3expesc       165 - 172
       pv4expesc       173 - 180
       pv5expesc       181 - 188
       wvarstrr        189 - 190
       w_fstr1         191 - 201
       w_fstr2         202 - 212
       w_fstr3         213 - 223
       w_fstr4         224 - 234
       w_fstr5         235 - 245
       w_fstr6         246 - 256
       w_fstr7         257 - 267
       w_fstr8         268 - 278
       w_fstr9         279 - 289
       w_fstr10        290 - 300
       w_fstr11        301 - 311
       w_fstr12        312 - 322
       w_fstr13        323 - 333
       w_fstr14        334 - 344
       w_fstr15        345 - 355
       w_fstr16        356 - 366
       w_fstr17        367 - 377
       w_fstr18        378 - 388
       w_fstr19        389 - 399
       w_fstr20        400 - 410
       w_fstr21        411 - 421
       w_fstr22        422 - 432
       w_fstr23        433 - 443
       w_fstr24        444 - 454
       w_fstr25        455 - 465
       w_fstr26        466 - 476
       w_fstr27        477 - 487
       w_fstr28        488 - 498
       w_fstr29        499 - 509
       w_fstr30        510 - 520
       w_fstr31        521 - 531
       w_fstr32        532 - 542
       w_fstr33        543 - 553
       w_fstr34        554 - 564
       w_fstr35        565 - 575
       w_fstr36        576 - 586
       w_fstr37        587 - 597
       w_fstr38        598 - 608
       w_fstr39        609 - 619
       w_fstr40        620 - 630
       w_fstr41        631 - 641
       w_fstr42        642 - 652
       w_fstr43        653 - 663
       w_fstr44        664 - 674
       w_fstr45        675 - 685
       w_fstr46        686 - 696
       w_fstr47        697 - 707
       w_fstr48        708 - 718
       w_fstr49        719 - 729
       w_fstr50        730 - 740
       w_fstr51        741 - 751
       w_fstr52        752 - 762
       w_fstr53        763 - 773
       w_fstr54        774 - 784
       w_fstr55        785 - 795
       w_fstr56        796 - 806
       w_fstr57        807 - 817
       w_fstr58        818 - 828
       w_fstr59        829 - 839
       w_fstr60        840 - 850
       w_fstr61        851 - 861
       w_fstr62        862 - 872
       w_fstr63        873 - 883
       w_fstr64        884 - 894
       w_fstr65        895 - 905
       w_fstr66        906 - 916
       w_fstr67        917 - 927
       w_fstr68        928 - 938
       w_fstr69        939 - 949
       w_fstr70        950 - 960
       w_fstr71        961 - 971
       w_fstr72        972 - 982
       w_fstr73        983 - 993
       w_fstr74        994 - 1004
       w_fstr75       1005 - 1015
       w_fstr76       1016 - 1026
       w_fstr77       1027 - 1037
       w_fstr78       1038 - 1048
       w_fstr79       1049 - 1059
       w_fstr80       1060 - 1070
 ;

   LABEL
       nacional    = "Variable auxiliar para obtener promedios nacionales"
       escuela     = "Identificador de la escuela"
       id_ent      = "Entidad federativa (identificador numrico)"
       nom_ent     = "Entidad federativa"
       id_mod      = "Estrato escolar o Modalidad educativa (identificador numrico)"
       mod         = "Estrato escolar o Modalidad educativa"
       mageb05     = "ndice de marginacin urbana 2005"
       estrato     = "Estrato de muestreo. Se construy con ENTIDAD, MODALIDAD Y MARGINALIDAD. No es comn a todas las tablas pues en algunos casos se colapsaron registros"
       entest      = "Estratos del diseo muestral con el que se estiman los parmetros y errores estndar (Entidad federativa-Modalidad)"
       alumno      = "Identificador del alumno"
       id_instr    = "Identificador del cuadernillo de examen"
       sexo        = "Sexo del alumno"
       edad        = "Edad del alumno al mes de mayo de 2008, en aos (al momento de la aplicacin)"
       edadc       = "Edad del alumno al mes de mayo de 2008, codificada (al momento de la aplicacin)"
       edadn       = "Edad normativa"
       edad_ac     = "Edad en aos cumplidos (al momento de la aplicacin)"
       mes_nac     = "Mes de nacimiento del alumno (al momento de la aplicacin)"
       w_alu       = "Peso muestral o ponderador del alumno"
       docente     = "Identificador del docente que imparte clases al alumno"
       SR_01       = "Ortografa: palabras dentro de campo semntico"
       SR_30       = "Oraciones con sentido completo: cuento"
       SR_25       = "Narrador"
       SR_18       = "Propsito: cuento"
       SR_11       = "Coherencia: texto descriptivo"
       SR_21       = "Desarrollo cuento"
       SR_08       = "Oraciones con sentido completo: descripcin"
       SR_40       = "Coherencia: carta argumentativa"
       SR_13       = "Concordancia: texto descriptivo"
       SR_19       = "Congruencia extratextual: cuento"
       SR_23       = "Desenlace"
       SR_03       = "Propsito: texto breve"
       SR_20       = "Coherencia: cuento"
       SR_04       = "Cohesin/Coherencia"
       SR_43       = "Concordancia: carta argumentativa"
       SR_10       = "Cohesin: texto descriptivo"
       SR_34       = "Propsito: carta argumentativa"
       SR_06       = "Propsito: descripcin"
       SR_31       = "Concordancia: cuento"
       SR_29       = "Cohesin: cuento"
       SR_39       = "Cohesin: carta argumentativa"
       SR_38       = "Aceptabilidad del argumento"
       SR_24       = "Generacin de personajes"
       SR_26       = "Uso de descriptores: cuento"
       SR_46       = "Segmentacin: carta argumentativa"
       SR_16       = "Segmentacin: texto descriptivo"
       SR_02       = "Copia fiel: aforismo"
       SR_36       = "Pertinencia del argumento"
       SR_15       = "Puntuacin: texto descriptivo"
       SR_27       = "Presencia de dilogos: cuento"
       SR_33       = "Segmentacin: cuento"
       SR_09       = "Oracin temtica"
       SR_12       = "Uso de descriptores"
       SR_32       = "Uso correcto de puntuacin [, . ; -- ! ? comillas ( ) ]"
       SR_14       = "Ortografa: texto descriptivo"
       SR_45       = "Puntuacin: carta argumentativa"
       SR_37       = "Suficiencia del argumento"
       SR_05       = "Ortografa: texto breve"
       SR_44       = "Ortografa: carta argumentativa"
       SR_22       = "Clmax"
       SR_28       = "Creatividad: cuento"
       SR_17       = "Esquema de redaccin: cuento"
       SR_35       = "Pensamiento crtico"
       SR_41       = "Formato de la carta"
       SR_07       = "Idea creativa o pensamiento crtico"
       SR_42       = "Respuesta efectiva"
       pv1ExpEsc   = "Primer valor plausible de Escritura"
       pv2ExpEsc   = "Segundo valor plausible de Escritura"
       pv3ExpEsc   = "Tercer valor plausible de Escritura"
       pv4ExpEsc   = "Cuarto valor plausible de Escritura"
       pv5ExpEsc   = "Quinto valor plausible de Escritura"
       wvarstrr    = "Identificador del pseudoestrato (1 a 80) definido para el clculo de errores estndar con el mtodo de remuestreo BRR"
       w_fstr1     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr2     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr3     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr4     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr5     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr6     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr7     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr8     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr9     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr10    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr11    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr12    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr13    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr14    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr15    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr16    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr17    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr18    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr19    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr20    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr21    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr22    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr23    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr24    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr25    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr26    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr27    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr28    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr29    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr30    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr31    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr32    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr33    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr34    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr35    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr36    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr37    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr38    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr39    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr40    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr41    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr42    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr43    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr44    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr45    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr46    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr47    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr48    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr49    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr50    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr51    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr52    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr53    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr54    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr55    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr56    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr57    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr58    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr59    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr60    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr61    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr62    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr63    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr64    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr65    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr66    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr67    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr68    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr69    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr70    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr71    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr72    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr73    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr74    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr75    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr76    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr77    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr78    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr79    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr80    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
   ;

   FORMAT
       nacional           1.
       escuela            4.
       id_ent             id_entF.
       nom_ent            $char19.
       id_mod             id_modF.
       mod                $modF.
       mageb05            mageb05F.
       estrato            $char7.
       entest             $char6.
       alumno             5.
       id_instr           $char16.
       sexo               sexoF.
       edad               edadF.
       edadc              edadcF.
       edadn              edadnF.
       edad_ac            edad_acF.
       mes_nac            mes_nacF.
       docente            docenteF.
       sr_01              R1_R25F.
       sr_02              R1_R25F.
       sr_03              R1_R25F.
       sr_04              R1_R25F.
       sr_05              R1_R25F.
       sr_06              R1_R25F.
       sr_07              R1_R25F.
       sr_08              R1_R25F.
       sr_09              R1_R25F.
       sr_10              R1_R25F.
       sr_11              R1_R25F.
       sr_12              R1_R25F.
       sr_13              R1_R25F.
       sr_14              R1_R25F.
       sr_15              R1_R25F.
       sr_16              R1_R25F.
       sr_17              R1_R25F.
       sr_18              R1_R25F.
       sr_19              R1_R25F.
       sr_20              R1_R25F.
       sr_21              R1_R25F.
       sr_22              R1_R25F.
       sr_23              R1_R25F.
       sr_24              R1_R25F.
       sr_25              R1_R25F.
       sr_26              R1_R25F.
       sr_27              R1_R25F.
       sr_28              R1_R25F.
       sr_29              R1_R25F.
       sr_30              R1_R25F.
       sr_31              R1_R25F.
       sr_32              R1_R25F.
       sr_33              R1_R25F.
       sr_34              R1_R25F.
       sr_35              R1_R25F.
       sr_36              R1_R25F.
       sr_37              R1_R25F.
       sr_38              R1_R25F.
       sr_39              R1_R25F.
       sr_40              R1_R25F.
       sr_41              R1_R25F.
       sr_42              R1_R25F.
       sr_43              R1_R25F.
       sr_44              R1_R25F.
       sr_45              R1_R25F.
       sr_46              R1_R25F.
       wvarstrr           2.
   ;

/**************************************************************************
/*  Definicin de valores perdidos
/*   .N o N = No Administrado o no alcanzado.
/*   .M o M = Respuesta Mltiple.
/*   .S o S = Respuesta omitida (No contestado).
/*************************************************************************/
   IF  sexo = 8 THEN  sexo = .M;
   IF  edad_ac = 98 THEN  edad_ac = .M;
   IF  mes_nac = 98 THEN  mes_nac = .M;

   ARRAY perdidos1(3)  sexo edadc edadn;
   DO  i=1 TO 3;
         IF perdidos1{i}=9 THEN  perdidos1{i}= .S;
   END;

   ARRAY perdidos2(3)  edad edad_ac mes_nac;
   DO  i=1 TO 3;
         IF perdidos2{i}=99 THEN  perdidos2{i}= .S;
   END;

   IF  docente = 99999 THEN  docente = .S;

   ARRAY perdidos3(46)
                   sr_01 sr_02 sr_03 sr_04 sr_05 sr_06 sr_07 sr_08 sr_09
                   sr_10 sr_11 sr_12 sr_13 sr_14 sr_15 sr_16 sr_17 sr_18
                   sr_19 sr_20 sr_21 sr_22 sr_23 sr_24 sr_25 sr_26 sr_27
                   sr_28 sr_29 sr_30 sr_31 sr_32 sr_33 sr_34 sr_35 sr_36
                   sr_37 sr_38 sr_39 sr_40 sr_41 sr_42 sr_43 sr_44 sr_45 sr_46;
   DO  i=1 TO 46;
          IF perdidos3{i} = 5   THEN  perdidos3{i} = .N;
          IF perdidos3{i} = 6   THEN  perdidos3{i} = .N;
          IF perdidos3{i} = 7   THEN  perdidos3{i} = .N;
          IF perdidos3{i} = 8   THEN  perdidos3{i} = .M;
          IF perdidos3{i} = 9   THEN  perdidos3{i} = .S;
   END;

   drop i;
RUN;
